/*
 * Copyright (c) 2018. by Pablo Klaschka
 */

const storage = require('../helpers/storage');
const debugHelper = require("../helpers/debug");
const language = require("../helpers/language");

/**
 * @param {Selection} selection
 */
async function showModal(selection) {
    debugHelper.log('Showing TAT main modal');
    let options = await modalAsync(selection);
    return true;
}

/**
 * @param {Selection} selection
 */
async function modalAsync(selection) {
    return new Promise((resolve, reject) => {
        storage.get('settings', {}).then(settings => {
            debugHelper.log('Found settings: ', JSON.stringify(settings));


            // Removing old instances
            document.body.innerHTML = '';

            const dialog = document.createElement('dialog');
            dialog.id = 'settingsModal';
            dialog.innerHTML = `
    <style>    
    form {
        width: 360px;
    }
    </style>
    `;

            const form = document.createElement('form');
            form.method = 'dialog';

            const heading = document.createElement('h1');
            heading.innerHTML = language.getString('settingsTitle');
            form.appendChild(heading);

            const hReset = document.createElement('h2');
            hReset.innerHTML = language.getString('settingsResetHeading');
            form.appendChild(hReset);

            const pReset = document.createElement('p');
            pReset.innerHTML = language.getString('settingsResetText');
            form.appendChild(pReset);

            const btnReset = document.createElement('button');
            btnReset.innerHTML = language.getString('settingsResetButtonText');
            btnReset.addEventListener('click', evt => {
                storage.reset().then(value => {
                    btnReset.setAttribute('disabled', 'true');
                });
            });
            btnReset.setAttribute('uxp-variant', 'warning');
            form.appendChild(btnReset);

            const footer = document.createElement('footer');
            const btnOk = document.createElement('button');
            btnOk.id = "ok";
            btnOk.type = "submit";
            btnOk.innerHTML = language.getString('saveSettings');
            btnOk.setAttribute('uxp-variant', 'cta');
            btnOk.onclick = () => {
                storage.set('settings', {}).then(() => {
                    dialog.close();
                    resolve();
                    document.body.innerHTML = '';
                }).catch(reason => reject(reason));
            };
            btnOk.setAttribute('autofocus', 'autofocus');
            const btnCancel = document.createElement('button');
            btnCancel.id = "cancel";
            btnCancel.innerHTML = language.getString('cancel');
            btnCancel.onclick = () => {
                debugHelper.log("Closing Text Tools");
                dialog.close();
                reject();
                document.body.innerHTML = '';
            };
            footer.appendChild(btnCancel);
            footer.appendChild(btnOk);
            form.appendChild(footer);
            dialog.appendChild(form);
            document.body.appendChild(dialog);
            dialog.showModal().then(() => resolve()).catch(() => reject());
        }).catch(reason => reject(reason));

    });
}

function selectBox(label, entries, defaultValue) {
    const lblSelect = document.createElement("label");
    const spanLblSelect = document.createElement('span');
    spanLblSelect.innerHTML = label;
    lblSelect.appendChild(spanLblSelect);
    const select = document.createElement('select');

    for (let entry of entries) {
        let optEntry = document.createElement("option");
        optEntry.value = entry.value;
        optEntry.innerHTML = entry.label;
        select.appendChild(optEntry);
    }
    if (defaultValue) {
        select.value = defaultValue;
    }
    lblSelect.appendChild(select);

    return lblSelect;
}

module.exports = showModal;